@@ -97,10 +97,10 @@ class Migration(migrations.Migration):
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("partition",
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="partition_physicalvolume",
-                                   to="netbox_storage.partition")),
+                                   to="netbox_storage.partition", null=True)),
                 ("vg",
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="volumegroup_physicalvolume",
-                                   to="netbox_storage.volumegroup")),
+                                   to="netbox_storage.volumegroup", null=True)),
                 ("pv_name", models.CharField(max_length=255)),
                 ("drive",
                  models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="drive_physicalvolume",
