@@ -53,7 +53,7 @@ from netbox_storage.views import (
     LogicalVolumeBulkEditView,
     LogicalVolumeBulkDeleteView,
     LogicalVolumeView,
-    LogicalVolumeDeleteView, VolumeGroupPhysicalVolumeListView,
+    LogicalVolumeDeleteView, VolumeGroupPhysicalVolumeListView, DrivePhysicalVolumeListView,
 )
 
 app_name = "netbox_storage"
@@ -77,6 +77,7 @@ urlpatterns = [
         kwargs={"model": Drive},
     ),
     path("drive/<int:pk>/partition/", DrivePartitionListView.as_view(), name="drive_partitions"),
+    path("drive/<int:pk>/physicalvolume/", DrivePhysicalVolumeListView.as_view(), name="drive_physicalvolumes"),
     #
     # Filesystem urls
     #
